package statistics

import (
	"context"
	"github.com/pkg/errors"
	"live-service/app/user_center/model"
	"live-service/app/user_center/rpc/internal/svc"
	"live-service/app/user_center/rpc/pb"

	"github.com/zeromicro/go-zero/core/logx"
)

type StatPvpFirstBloodLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewStatPvpFirstBloodLogic(ctx context.Context, svcCtx *svc.ServiceContext) *StatPvpFirstBloodLogic {
	return &StatPvpFirstBloodLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

const (
	TypeFirstBlood   = 1
	TypeDeFirstBlood = 2
)

func (l *StatPvpFirstBloodLogic) StatPvpFirstBlood(in *pb.StatPvPFirstBloodReq) (*pb.Empty, error) {
	exists, _ := l.svcCtx.StatisticsPvpModel.Exists(l.ctx, in.Uid)
	if !exists {
		dbModel := &model.StatisticsPvp{
			UserId: in.Uid,
		}
		if in.Type == TypeFirstBlood {
			dbModel.FirstBloodCount = 1
		} else if in.Type == TypeDeFirstBlood {
			dbModel.DeFirstBloodCount = 1
		}
		if err := l.svcCtx.StatisticsPvpModel.Insert(l.ctx, dbModel); err != nil {
			return nil, errors.Wrapf(err, ErrInsertErr, err)
		}
		return &pb.Empty{}, nil
	}
	// 原始记录存在，直接更新，提高效率
	props := &model.UpdateRecordProps{}
	if in.Type == TypeFirstBlood {
		props.FirstBlood = true
	} else if in.Type == TypeDeFirstBlood {
		props.DeFirstBlood = true
	} else {
		l.Logger.Error("是否拿到一血 Type 有问题，不是1或2?")
		return &pb.Empty{}, nil
	}
	if err := l.svcCtx.StatisticsPvpModel.UpdateRecord(l.ctx, in.Uid, props); err != nil {
		return nil, errors.Wrapf(err, ErrUpdateErr, err)
	}
	return &pb.Empty{}, nil
}
