package statistics

import (
	"context"
	"github.com/pkg/errors"
	"live-service/app/user_center/model"

	"live-service/app/user_center/rpc/internal/svc"
	"live-service/app/user_center/rpc/pb"

	"github.com/zeromicro/go-zero/core/logx"
)

type StatPvpReportLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewStatPvpReportLogic(ctx context.Context, svcCtx *svc.ServiceContext) *StatPvpReportLogic {
	return &StatPvpReportLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

func (l *StatPvpReportLogic) StatPvpReport(in *pb.StatPvPReportReq) (*pb.Empty, error) {
	// 名将
	exists, _ := l.svcCtx.StatisticsPvpModel.Exists(l.ctx, in.GeneralUid)
	if !exists {
		dbModel := &model.StatisticsPvp{
			UserId:       in.GeneralUid,
			GeneralCount: 1,
		}
		if err := l.svcCtx.StatisticsPvpModel.Insert(l.ctx, dbModel); err != nil {
			return nil, errors.Wrapf(err, ErrInsertErr, err)
		}
		return &pb.Empty{}, nil
	}
	if err := l.svcCtx.StatisticsPvpModel.UpdateRecord(l.ctx, in.GeneralUid, &model.UpdateRecordProps{General: true}); err != nil {
		return nil, errors.Wrapf(err, ErrUpdateErr, err)
	}
	// 获胜记录
	// 战败记录
	if err := l.svcCtx.StatisticsPvpModel.RecordPvp(l.ctx, in.WinUids, in.LostUids); err != nil {
		return nil, errors.Wrapf(err, ErrUpdateErr, err)
	}
	return &pb.Empty{}, nil
}
